package com.hw.system.common.service;

import java.util.List;
import com.hw.system.common.domain.WfProcess;

/**
 * 工单流程Service接口
 *
 * @author xins
 * @date 2024-01-19
 */
public interface IWfProcessService
{
    /**
     * 查询工单流程
     *
     * @param wfProcessId 工单流程主键
     * @return 工单流程
     */
    public WfProcess selectWfProcessByWfProcessId(Long wfProcessId);

    /**
     * 查询工单流程列表
     *
     * @param wfProcess 工单流程
     * @return 工单流程集合
     */
    public List<WfProcess> selectWfProcessList(WfProcess wfProcess);

    /**
     * 新增工单流程
     *
     * @param wfProcess 工单流程
     * @return 结果
     */
    public int insertWfProcess(WfProcess wfProcess);

    /**
     * 修改工单流程
     *
     * @param wfProcess 工单流程
     * @return 结果
     */
    public int updateWfProcess(WfProcess wfProcess);

    /**
     * 批量删除工单流程
     *
     * @param wfProcessIds 需要删除的工单流程主键集合
     * @return 结果
     */
    public int deleteWfProcessByWfProcessIds(Long[] wfProcessIds);

    /**
     * 删除工单流程信息
     *
     * @param wfProcessId 工单流程主键
     * @return 结果
     */
    public int deleteWfProcessByWfProcessId(Long wfProcessId);
}
